dnl Local extensions macros to Autoconf.
dnl Copyright (C) 1994, 1995  Per Cederqvist and Inge Wallin
dnl
dnl This program is free software; you can redistribute it and/or modify
dnl it under the terms of the GNU General Public License as published by
dnl the Free Software Foundation; either version 2 of the License, or
dnl (at your option) any later version.
dnl 
dnl This program is distributed in the hope that it will be useful,
dnl but WITHOUT ANY WARRANTY; without even the implied warranty of
dnl MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
dnl GNU General Public License for more details.
dnl 
dnl You should have received a copy of the GNU General Public License
dnl along with this program; if not, write to the Free Software
dnl Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
dnl
dnl
dnl
dnl Check if an option is acceptable to the C compiler in use
dnl
AC_DEFUN(KOM_COMPILER_CC_ACCEPTS,
[kom_safe=`echo "kom_cv_compiler_${CC}_accepts_$1" | tr '+./=\055' 'X____'`
AC_MSG_CHECKING([whether ${CC} accepts $1])
AC_CACHE_VAL($kom_safe,
[[kom_oldflags=$CFLAGS
CFLAGS="$CFLAGS $1"]
AC_TRY_LINK(,,
	[eval "$kom_safe=yes"],
	[eval "$kom_safe=no"])
[CFLAGS=$kom_oldflags]])dnl
AC_MSG_RESULT([`eval echo '$'$kom_safe`])
if test `eval echo '$'$kom_safe` = yes; then
  CFLAGS="$CFLAGS $1"
fi])dnl
dnl
dnl
dnl Check if an option is acceptable to the C++ compiler in use
dnl
AC_DEFUN(KOM_COMPILER_CXX_ACCEPTS,
[kom_safe=`echo "kom_cv_compiler_${CXX}_accepts_$1" | tr '+./=\055' 'X____'`
AC_MSG_CHECKING([whether ${CXX} accepts $1])
AC_CACHE_VAL($kom_safe,
[[kom_oldflags=$CXXFLAGS
CXXFLAGS="$CXXFLAGS $1"]
AC_TRY_LINK(,,
	[eval "$kom_safe=yes"],
	[eval "$kom_safe=no"])
[CXXFLAGS=$kom_oldflags]])dnl
AC_MSG_RESULT([`eval echo '$'$kom_safe`])
if test `eval echo '$'$kom_safe` = yes; then
  CXXFLAGS="$CXXFLAGS $1"
fi])dnl
dnl
dnl
dnl Check that "struct std::iterator" is available in <iterator>.
dnl The STL supplied with gcc-2.95.2 does contain a proper struct
dnl iterator, but it doesn't make it available when compiled with 
dnl gcc...
dnl
AC_DEFUN(KOM_STL_STRUCT_ITERATOR,
[AC_MSG_CHECKING([whether struct std::iterator<> is available in <iterator>])
AC_CACHE_VAL(kom_cv_stl_struct_iterator,
	AC_TRY_COMPILE([#include <iterator>],
		[class foo : public std::iterator<
			std::forward_iterator_tag, int, int, int*, int&>
		{
		public: foo();
		}
		foo bar;],
		[kom_cv_stl_struct_iterator=yes],
		[kom_cv_stl_struct_iterator=no]))
AC_MSG_RESULT([$kom_cv_stl_struct_iterator])
[if test $kom_cv_stl_struct_iterator = no; then]
  AC_DEFINE(NEED_STRUCT_ITERATOR)
[fi]])
dnl
dnl
dnl Find stuff about the Python installation.
dnl This sets PYTHON_BOOTMAKEFILE and PYTHON_INCLUDES.
dnl
AC_DEFUN(KOM_PYTHON_PATHS,
[[if test x$1 = x
then
    PYTHON_BOOTMAKEFILE=
    PYTHON_INCLUDES=
else]
    AC_MSG_CHECKING([for Python bootmakefile])
    AC_CACHE_VAL(kom_cv_prog_python_bootmakefile,
    [[cat > conftestpy.py << \EOF
import sys
import string

try:
    v="%d.%d" % (sys.version_info[0], sys.version_info[1])
except AttributeError:
    v=sys.version[:3]

pfx = [sys.prefix]
if sys.exec_prefix != sys.prefix:
    pfx.append(sys.exec_prefix)

print "kom_cv_prog_python_bootmakefile=%s/lib/python%s/%s" % (
	sys.exec_prefix, v, "config/Makefile.pre.in")
print "kom_cv_prog_python_includes=\"%s\"" % string.join(
    map(lambda p, v=v: "-I%s/include/python%s" % (p, v), pfx), " ")
EOF

    if $1 conftestpy.py > conftestpy.sh
    then
        . ./conftestpy.sh
    else]]
        AC_MSG_ERROR([cannot find python binary $1])
    [[fi]])
    AC_MSG_RESULT($kom_cv_prog_python_bootmakefile)
    AC_MSG_CHECKING([for Python include files])
    AC_MSG_RESULT($kom_cv_prog_python_includes)
    [PYTHON_BOOTMAKEFILE="$kom_cv_prog_python_bootmakefile"
    PYTHON_INCLUDES="$kom_cv_prog_python_includes"
fi]
AC_SUBST(PYTHON_BOOTMAKEFILE)
AC_SUBST(PYTHON_INCLUDES)
])dnl
dnl eof
